﻿using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace TextEditorInGridCaptureTextONntering
{
    public partial class Form1 : Form
    {
        private MyControlContainerEditor myControlContainerEditor;
        ucTextCol utc1 = new ucTextCol();
        ucTextCol utc2 = new ucTextCol();
        public Form1()
        {
            InitializeComponent();
            this.ultraGrid1.CellChange += UltraGrid1_CellChange;
            this.ultraGrid1.DisplayLayout.Bands[0].Override.CellClickAction = CellClickAction.Edit;

            // We need to expose a way to call the protected RaiseValueChangeEvent method on the ControlContainerEditor. 
            // So instead of using the UltraControlContainerEditor component, use the MyControlContainerEditor, instead. 
            myControlContainerEditor = new MyControlContainerEditor();
            myControlContainerEditor.EditingControlPropertyName = "TextCol";
            myControlContainerEditor.RenderingControlPropertyName = "TextCol";
            myControlContainerEditor.EnterEditModeMouseBehavior = Infragistics.Win.UltraWinEditors.EnterEditModeMouseBehavior.EnterEditModeAndClick;
            

            // Trap the TextChanged event of the EditingControl. 
            // Note that TextChanged is an event on Control, but it's hidden from Intellisense. 
            this.utc1.TextChanged += Utc1_TextChanged;
        }
        private void Utc1_TextChanged(object sender, EventArgs e)
        {
            // Whenever the TextChanged of the EditingControl fires, raise a ValueChanged event on the ControlContainerEditor. 
            // This is what the grid listens to in order to fire the CellChange event. 
            this.myControlContainerEditor.RaiseValueChangeEventInternal();    
        }
           
        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.UpdateMode = UpdateMode.OnCellChangeOrLostFocus;
            
            myControlContainerEditor.EditingControl = utc1;
            myControlContainerEditor.RenderingControl = utc2;

            DataTable dt = new DataTable();
            dt.Columns.Add("ID"); dt.Columns.Add("Text", typeof(TextCol));
            
            dt.Rows.Add("0", new TextCol("44"));
            dt.Rows.Add("1", new TextCol("Text 1"));
            dt.Rows.Add("2", new TextCol("Text 2"));
            dt.Rows.Add("3", new TextCol("Text 3"));
            dt.Rows.Add("4", new TextCol("Text 4"));
            dt.Rows.Add("5", new TextCol("Text 5"));
            ultraGrid1.DataSource = dt;
        }

        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            // Use the editor instead, because we need to create out own derived editor class. 
            //e.Layout.Bands[0].Columns["Text"].EditorCompoennt = ultraControlContainerEditor1;
            e.Layout.Bands[0].Columns["Text"].Editor = myControlContainerEditor;

            e.Layout.Bands[0].Columns["Text"].Width = 200;
            e.Layout.Override.DefaultRowHeight = 50;
        }

        private void UltraGrid1_CellChange(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            this.VerifyCellAppearance(e.Cell.Row);
        }

        private void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            this.VerifyCellAppearance(e.Row);
        }

        private void VerifyCellAppearance(UltraGridRow row)
        {
            var cell = row.Cells[1];
            string cl1 = ((TextCol)(cell.Value)).Txt;
            if (cl1 == "44")
            {
                cell.Appearance.BackColor = Color.Yellow;
                cell.Appearance.ForeColor = Color.Red;

                cell.SelectedAppearance.BackColor = Color.Yellow;
                cell.SelectedAppearance.ForeColor = Color.Red;

                cell.ActiveAppearance.BackColor = Color.Yellow;
                cell.ActiveAppearance.ForeColor = Color.Red;                
            }
            else
            {
                cell.Appearance.ResetBackColor();
                cell.Appearance.ResetForeColor();

                cell.SelectedAppearance.ResetBackColor();
                cell.SelectedAppearance.ResetForeColor();

                cell.ActiveAppearance.ResetBackColor();
                cell.ActiveAppearance.ResetForeColor();
            }

            if (cell.IsInEditMode)
            {
                var appearance = new AppearanceData();
                var appearancePropFlags = AppearancePropFlags.BackColor | AppearancePropFlags.ForeColor;
                cell.ResolveAppearance(ref appearance, appearancePropFlags);
                myControlContainerEditor.ApplyEditingControlAppearance(ref appearance);
            }
        }
    }
}
